@@ -38,6 +38,12 @@ density.dist_logarithmic <- function(x, at, ...){
   actuar::dlogarithmic(at, x[["p"]])
 }
 
+#' @export
+log_density.dist_logarithmic <- function(x, at, ...){
+  require_package("actuar")
+  actuar::dlogarithmic(at, x[["p"]], log = TRUE)
+}
+
 #' @export
 quantile.dist_logarithmic <- function(x, p, ...){
   require_package("actuar")
